@@ -78,11 +78,11 @@ static void initialize_tags(GtkTextBuffer *buffer) {
 
 	gtk_text_buffer_create_tag(buffer, "_title", "foreground", "blue", "underline", PANGO_UNDERLINE_SINGLE, "scale", PANGO_SCALE_X_LARGE, NULL);
 
-	gtk_text_buffer_create_tag(buffer, "list-item", NULL);
-	gtk_text_buffer_create_tag(buffer, "list", NULL);
+	//gtk_text_buffer_create_tag(buffer, "list-item", NULL);
+	//gtk_text_buffer_create_tag(buffer, "list", NULL);
 
-	//gtk_text_buffer_create_tag(buffer, "list-item", "foreground", "orange", NULL);
-	//gtk_text_buffer_create_tag(buffer, "list", "background", "gray", NULL);
+	gtk_text_buffer_create_tag(buffer, "list-item", "foreground", "orange", NULL);
+	gtk_text_buffer_create_tag(buffer, "list", "background", "gray", NULL);
 }
 
 static void
@@ -147,7 +147,7 @@ on_orientation_changed(GdkScreen *screen, gpointer data)
 
 		/* Other */
 		gtk_text_view_set_editable(ui->view, FALSE);
-		/*hildon_gtk_text_view_set_input_mode(GTK_TEXT_VIEW(ui->view), HILDON_GTK_INPUT_MODE_FULL | HILDON_GTK_INPUT_MODE_AUTOCAP | HILDON_GTK_INPUT_MODE_NO_SCREEN_PLUGINS);*/
+		gtk_text_view_set_cursor_visible(ui->view, FALSE);
 
 	} else {
 		/* Toolbar */
@@ -166,7 +166,7 @@ on_orientation_changed(GdkScreen *screen, gpointer data)
 
 		/* Other */
 		gtk_text_view_set_editable(ui->view, TRUE);
-		/*hildon_gtk_text_view_set_input_mode(GTK_TEXT_VIEW(ui->view), HILDON_GTK_INPUT_MODE_FULL | HILDON_GTK_INPUT_MODE_AUTOCAP);*/
+		gtk_text_view_set_cursor_visible(ui->view, TRUE);
 	}
 }
 
@@ -1176,7 +1176,7 @@ UserInterface* create_mainwin() {
 			ui);
 
 	g_signal_connect_after ((gpointer)buffer, "delete-range",
-			G_CALLBACK(on_text_buffer_delete_range),
+			G_CALLBACK(after_text_buffer_delete_range),
 			ui);
 
 	g_signal_connect((gpointer)find_bar, "search",
